==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/FinancialOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FinancialOverlayDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialOverlayDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialOverlayDescriptionMetadata.a == null) {
                FinancialOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialOverlayDescriptionMetadata.c(FinancialOverlayDescriptionMetadata.a);
            }
            if (a.j(FinancialOverlayDescriptionMetadata.a)) {
                return;
            }
            a.y(FinancialOverlayDescriptionMetadata.a);
        }
        static c(a) {
            FinancialSeriesDescriptionMetadata.c(a);
            a.item("IgnoreFirst", "Number:int");
        }
        static d(a) {
            FinancialOverlayDescriptionMetadata.b(a);
            a.z("FinancialOverlay", FinancialOverlayDescriptionMetadata.a);
        }
    }
    FinancialOverlayDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialOverlayDescriptionMetadata, 'FinancialOverlayDescriptionMetadata');
    FinancialOverlayDescriptionMetadata.a = null;
    return FinancialOverlayDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FinancialOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FinancialOverlayDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialOverlayDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialOverlayDescriptionMetadata.a == null) {
                FinancialOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialOverlayDescriptionMetadata.c(FinancialOverlayDescriptionMetadata.a);
            }
            if (a.k(FinancialOverlayDescriptionMetadata.a)) {
                return;
            }
            a.aa(FinancialOverlayDescriptionMetadata.a);
        }
        static c(a) {
            FinancialSeriesDescriptionMetadata.c(a);
            a.item("IgnoreFirst", "Number:int");
        }
        static d(a) {
            FinancialOverlayDescriptionMetadata.b(a);
            a.ab("FinancialOverlay", FinancialOverlayDescriptionMetadata.a);
        }
    }
    FinancialOverlayDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialOverlayDescriptionMetadata, 'FinancialOverlayDescriptionMetadata');
    FinancialOverlayDescriptionMetadata.a = null;
    return FinancialOverlayDescriptionMetadata;
})();
